#include <sys/time.h>
#include <sys/sysctl.h>
#include <stdlib.h>
#include <stdio.h>
#include <libgen.h>
#include <string.h>
#include <assert.h>

static const char *progname;

static void
usage(int rc)
{
	fprintf(stderr, "Usage: %s [year]\n"
	    "    if a year is specified it must be between 1970 and 2069\n"
	    "    if a year is not specified a random one is chosen\n",
	    progname);

	exit(rc);
}

int
main(int argc, char *argv[])
{
	struct tm tm;
	struct timeval tv;
	int c, error, i, year;

	progname = basename(argv[0]);

	year = 0;
	if (argc > 1)
		year = atoi(argv[1]);
	else
		year = 1970 + random() % 100;

	if (year < 1970 || year > 2069)
		usage(1);
	else
		printf("year %d\n", year);

	bzero(&tm, sizeof(struct tm));
	tm.tm_mday = 1;
	tm.tm_year = year - 1900;
	tv.tv_sec = timegm(&tm);
	tv.tv_usec = 0;

	for (i = 0; i < 86400 * 365; i++) {
		error = settimeofday(&tv, NULL);
		assert(error == 0);
		tv.tv_sec++;

		/* Display weekly progress */
		if ((tv.tv_sec % (86400 * 7)) == 0) {
			putchar('.');
			fflush(stdout);
		}
	}
	putchar('\n');
	exit(0);
}
